@@ -11,6 +11,8 @@ from .types import (
     instrumented_list,
     InstrumentedList,
     IPAddressType,
+    Password,
+    PasswordType,
     PhoneNumber,
     PhoneNumberType,
     NumberRange,
@@ -24,7 +26,7 @@ from .types import (
 )
 
 
-__version__ = '0.14.7'
+__version__ = '0.15.0'
 
 
 __all__ = (
@@ -47,6 +49,8 @@ __all__ = (
     NumberRangeException,
     NumberRangeRawType,
     NumberRangeType,
+    Password,
+    PasswordType,
     PhoneNumber,
     PhoneNumberType,
     ProxyDict,
